@@ -26,13 +26,22 @@ def wait_for_key(
     oldterm = termios.tcgetattr(fd)
     newattr = termios.tcgetattr(fd)
     newattr[3] = newattr[3] & ~termios.ICANON & ~termios.ECHO
-    termios.tcsetattr(fd, termios.TCSANOW, newattr)
+
+    termios.tcsetattr(
+        fd,
+        termios.TCSANOW,
+        newattr
+    )
 
     try:
         result = sys.stdin.read(1)
     except IOError:
         pass
     finally:
-        termios.tcsetattr(fd, termios.TCSAFLUSH, oldterm)
+        termios.tcsetattr(
+            fd,
+            termios.TCSAFLUSH,
+            oldterm
+        )
 
     return result
