@@ -10,7 +10,7 @@ import unittest
 sys.path.append(".")
 
 from print_tools import \
-    format_filesize
+    format_filesize, print_
 
 
 class TestSystem(unittest.TestCase):
@@ -22,6 +22,15 @@ class TestSystem(unittest.TestCase):
                     prefix_type=prefix_type
                 ))
 
+    def test_print_(self):
+        print_(
+            'Das ist ein Test',
+            'mit Ümläuten und Zeilenenden', '\n',
+            'bla bla bla',
+            color={2: 'red'},
+            sep='#'
+        )
+
 
 if __name__ == '__main__':
     unittest.main()
